@@ -4,7 +4,7 @@ archinfo is a collection of classes that contain architecture-specific informati
 It is useful for cross-architecture tools (such as pyvex).
 """
 
-__version__ = "9.2.102"
+__version__ = "9.2.134"
 
 
 from .arch import (
@@ -31,7 +31,6 @@ from .arch_s390x import ArchS390X
 from .arch_soot import ArchSoot
 from .arch_x86 import ArchX86
 from .archerror import ArchError
-from .defines import defines
 from .types import Endness, RegisterName, RegisterOffset, TmpVar
 
 __all__ = [
@@ -61,7 +60,6 @@ __all__ = [
     "TmpVar",
     "all_arches",
     "arch_from_id",
-    "defines",
     "get_host_arch",
     "register_arch",
     "reverse_ends",
